==> mcg_extension-1.0.0.tar.gz: lib/extensions/stringextension.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher.dart' as launcher;

import '../constants.dart';
import '../get/alert.dart';
import '../get/translate.dart';
import 'intextension.dart';

extension MyString on String? {
  /// Karakter Sayisini soyler. null ise -1 gelir
  //int get mcgLength => this == null ? -1 : length;
  int get safeLength => this == null ? -1 : this!.length;

  /// enumlar icin son noktadan sonraki kelimeyi verir
  String get afterDot {
    if (this == null) return '';
    return this!.split('.').last;
  }

  ///Search icin kucultur ve turkce karakterler icin duzen saglar
  String toSearchCase() {
    if (this == null) return '';
    return this!.replaceAll('I', 'i').replaceAll('ı', 'i').replaceAll('İ', 'i').toLowerCase().replaceAll('ü', 'u').replaceAll('ğ', 'g').replaceAll('ş', 's').replaceAll('ç', 'c').replaceAll('ö', 'o');
  }

  ///Guvenli sekilde ilk x karakteri verir
  String? firstXcharacter(int characterCount) {
    if (this == null) return null;
    if (this!.length < characterCount) return this;
    return this!.substring(0, characterCount);
  }

  ///Guvenli sekilde son x karakteri verir
  String? lastXcharacter(int characterCount) {
    if (this == null) return null;
    if (this!.length < characterCount) return this;
    return this!.substring(this!.length - characterCount, this!.length);
  }

  ///Guvenli sekilde kirpar
  String? safeSubString(int start, int end) {
    if (this == null) return null;
    if (start < 0 || end < 0) return '';
    if (this!.length < start) return '';
    if (this!.length < end) end = this!.length;
    return this!.substring(start, end);
  }

  /// Firebase icin gecersiz karakterleri gecerli hale getirir. gecersizler yerine iki nokta ustuste koyar
  String? get toFirebaseSafeKey {
    if (this == null) return null;
    return this!.replaceAll('.', ':').replaceAll('"\$"', ':').replaceAll('[', ':').replaceAll(']', ':').replaceAll('#', ':').replaceAll('/', ':').replaceAll('\\', ':').replaceAll('-', ':').replaceAll('%', ':').replaceAll('@', 'ISARETET');
  }

  String? get removeFirebaseForbiddenCharacters {
    if (this == null) return null;
    return this!.replaceAll('.', '').replaceAll('"\$"', '').replaceAll('[', '').replaceAll(']', '').replaceAll('#', '').replaceAll('/', '').replaceAll('\\', '').replaceAll('-', '').replaceAll('%', '').replaceAll('@', '');
  }

  bool get hasFirebaseForbiddenCharacter {
    if (this == null) return true;
    return this!.contains('.') || this!.contains('\$') || this!.contains('[') || this!.contains(']') || this!.contains('#') || this!.contains('/') || this!.contains('\\') || this!.contains('-') || this!.contains('%') || this!.contains('@');
  }

  /// Email se true doner
  bool get isEmail {
    if (this == null) return false;
    return GetUtils.isEmail(this!);
  }

  /// haneli regex kodunu renge cevirir
  Color get parseColor => this == null ? Colors.transparent : Color(int.parse('0xff${this!.replaceFirst('#', '')}'));

  /// herhangi bir linkten youtube id sini cikartir. eger link yanlisssa null doner
  String? get getYoutubeIdFromUrl {
    var _regexps = [RegExp(r"^https:\/\/(?:www\.|m\.)?youtube\.com\/watch\?v=([_\-a-zA-Z0-9]{11}).*$"), RegExp(r"^https:\/\/(?:www\.|m\.)?youtube(?:-nocookie)?\.com\/embed\/([_\-a-zA-Z0-9]{11}).*$"), RegExp(r"^https:\/\/youtu\.be\/([_\-a-zA-Z0-9]{11}).*$")];

    if (safeLength < 3) return null;

    for (var exp in _regexps) {
      Match? match = exp.firstMatch(this!.trim());
      if (match != null && match.groupCount >= 1) return match.group(1);
    }
    return null;
  }

  /// ingilizce olmayan kaakterleri temizler
  String? get removeNonEnglishCharacter {
    if (this == null) return null;
    return this!.split('').fold<String>('', (previousValue, element) => englishCharacters.contains(element) ? previousValue + element : previousValue);
  }

  String? get changeTurkishCharacter {
    if (this == null) return null;
    return this!.replaceAll('Ş', 'S').replaceAll('ş', 's').replaceAll('Ç', 'C').replaceAll('ç', 'c').replaceAll('Ü', 'U').replaceAll('ü', 'u').replaceAll('Ö', 'O').replaceAll('ö', 'o').replaceAll('Ğ', 'G').replaceAll('ğ', 'g').replaceAll('İ', 'I').replaceAll('ı', 'i');
  }

  /// Text Widgetir donturur
  // Widget mcgText({Color color, double fontSize, FontWeight fontWeight, int maxLines, TextAlign textAlign = TextAlign.start}) {
  //   return Text(
  //     this,
  //     maxLines: maxLines,
  //     textAlign: textAlign,
  //     style: TextStyle(color: color, fontSize: fontSize, fontWeight: fontWeight),
  //   );
  // }

  ///BaslangiciBuyukYapar
  String? get capitalize => safeLength == 0
      ? this
      : safeLength == 1
          ? this!.toUpperCase()
          : this!.substring(0, 1).toUpperCase() + this!.substring(1);

  //kelimelerin sadece bas harflerini birlestirip buyutur
  String? get onlyCapitalLetters => safeLength == 0 ? this : (this!.split(" ").fold<String>('', (p, e) => e.safeLength > 0 ? p + e.substring(0, 1).toUpperCase() : p));

  ///String SiteUrl Sms Mail tel  ve map acar
  ///Map icin lat ve lon arasina / koy
  Future<void> launch(LaunchType launchType, {String mailSubject = ''}) async {
    late String item;
    if (launchType == LaunchType.mail) {
      item = 'mailto:$this?subject=$mailSubject';
    } else if (launchType == LaunchType.url) {
      if (!this!.startsWith('http')) {
        item = 'https://$this';
      } else {
        item = this!;
      }
    } else if (launchType == LaunchType.call) {
      item = 'tel:$this';
    } else if (launchType == LaunchType.sms) {
      item = 'sms:$this';
    } else if (launchType == LaunchType.map) {
      item = 'https://www.google.com/maps/search/?api=1&query=${this!.split('/').first},${this!.split('/').last}';
    }
    if (await launcher.canLaunch(item)) {
      await launcher.launch(item);
    } else {
      Alert.show(
        message: (launchType == LaunchType.mail
                ? 'mailerr'
                : launchType == LaunchType.url
                    ? 'linkerr'
                    : launchType == LaunchType.sms || launchType == LaunchType.call
                        ? 'numbererr'
                        : 'dataerr')
            .translate,
        type: AlertType.danger,
      );
    }
  }

  void showAlert([AlertType? alertType]) => Alert.alert(message: this!, type: alertType ?? AlertType.info);

  String? get mix {
    if (safeLength < 6) return this;
    var res = this! + 6.makeKey;
    for (var i = 0; i < res.length ~/ 2; i++) {
      res = res.substring(res.length - (i + 1)) + res.substring(i + 1, res.length - (i + 1)) + res.substring(0, i + 1);
    }
    return res;
  }

  String? get unMix {
    if (safeLength < 6) return this;
    var res = this!;
    for (var i = res.length ~/ 2 - 1; i > -1; i--) {
      res = res.substring(res.length - (i + 1)) + res.substring(i + 1, res.length - (i + 1)) + res.substring(0, i + 1);
    }
    return res.substring(0, res.length - 6);
  }

  String changeCharacter(int? no, String? character) {
    if (no == null || character == null || this == null) return this!;
    if (no >= this!.length) return this!;
    return this!.substring(0, no) + character + this!.substring(no + 1);
  }
}

enum LaunchType { url, mail, call, sms, map }

// extension MyObject on Object {
//   void selfPrint([String name]) => print('***** ${name == null ? '' : '$name: '}$this *****');
// }

==> mcg_extension-1.0.1.tar.gz: lib/extensions/stringextension.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:url_launcher/url_launcher.dart' as launcher;

import '../constants.dart';
import '../enums.dart';
import '../get/translate.dart';
import '../over/over.dart';
import 'intextension.dart';

extension MyString on String? {
  /// Karakter Sayisini soyler. null ise -1 gelir
  //int get mcgLength => this == null ? -1 : length;
  int get safeLength => this == null ? -1 : this!.length;

  /// enumlar icin son noktadan sonraki kelimeyi verir
  String get afterDot {
    if (this == null) return '';
    return this!.split('.').last;
  }

  ///Search icin kucultur ve turkce karakterler icin duzen saglar
  String toSearchCase() {
    if (this == null) return '';
    return this!.replaceAll('I', 'i').replaceAll('ı', 'i').replaceAll('İ', 'i').toLowerCase().replaceAll('ü', 'u').replaceAll('ğ', 'g').replaceAll('ş', 's').replaceAll('ç', 'c').replaceAll('ö', 'o');
  }

  ///Guvenli sekilde ilk x karakteri verir
  String? firstXcharacter(int characterCount) {
    if (this == null) return null;
    if (this!.length < characterCount) return this;
    return this!.substring(0, characterCount);
  }

  ///Guvenli sekilde son x karakteri verir
  String? lastXcharacter(int characterCount) {
    if (this == null) return null;
    if (this!.length < characterCount) return this;
    return this!.substring(this!.length - characterCount, this!.length);
  }

  ///Guvenli sekilde kirpar
  String? safeSubString(int start, int end) {
    if (this == null) return null;
    if (start < 0 || end < 0) return '';
    if (this!.length < start) return '';
    if (this!.length < end) end = this!.length;
    return this!.substring(start, end);
  }

  /// Firebase icin gecersiz karakterleri gecerli hale getirir. gecersizler yerine iki nokta ustuste koyar
  String? get toFirebaseSafeKey {
    if (this == null) return null;
    return this!
        .replaceAll('.', ':')
        .replaceAll('\$', ':')
        .replaceAll('[', ':')
        .replaceAll(']', ':')
        .replaceAll('#', ':')
        .replaceAll('/', ':')
        .replaceAll('\\', ':')
        // .replaceAll('-', ':')
        .replaceAll('%', ':')
        .replaceAll('@', 'ISARETET');
  }

  String? get removeFirebaseForbiddenCharacters {
    if (this == null) return null;
    return this!
        .replaceAll('.', '')
        .replaceAll('\$', '')
        .replaceAll('[', '')
        .replaceAll(']', '')
        .replaceAll('#', '')
        .replaceAll('/', '')
        .replaceAll('\\', '')
        // .replaceAll('-', '')
        .replaceAll('%', '')
        .replaceAll('@', '');
  }

  bool get hasFirebaseForbiddenCharacter {
    if (this == null) return true;
    return this!.contains('.') ||
        this!.contains('\$') ||
        this!.contains('[') ||
        this!.contains(']') ||
        this!.contains('#') ||
        this!.contains('/') ||
        this!.contains('\\') ||
        // this!.contains('-')||
        this!.contains('%') ||
        this!.contains('@');
  }

  /// Email se true doner
  bool get isEmail {
    if (this == null) return false;
    return GetUtils.isEmail(this!);
  }

  /// haneli regex kodunu renge cevirir
  Color get parseColor => this == null ? Colors.transparent : Color(int.parse('0xff${this!.replaceFirst('#', '')}'));

  /// herhangi bir linkten youtube id sini cikartir. eger link yanlisssa null doner
  String? get getYoutubeIdFromUrl {
    var _regexps = [RegExp(r"^https:\/\/(?:www\.|m\.)?youtube\.com\/watch\?v=([_\-a-zA-Z0-9]{11}).*$"), RegExp(r"^https:\/\/(?:www\.|m\.)?youtube(?:-nocookie)?\.com\/embed\/([_\-a-zA-Z0-9]{11}).*$"), RegExp(r"^https:\/\/youtu\.be\/([_\-a-zA-Z0-9]{11}).*$")];

    if (safeLength < 3) return null;

    for (var exp in _regexps) {
      Match? match = exp.firstMatch(this!.trim());
      if (match != null && match.groupCount >= 1) return match.group(1);
    }
    return null;
  }

  /// ingilizce olmayan kaakterleri temizler
  String? get removeNonEnglishCharacter {
    if (this == null) return null;
    return this!.split('').fold<String>('', (previousValue, element) => englishCharacters.contains(element) ? previousValue + element : previousValue);
  }

  String? get changeTurkishCharacter {
    if (this == null) return null;
    return this!.replaceAll('Ş', 'S').replaceAll('ş', 's').replaceAll('Ç', 'C').replaceAll('ç', 'c').replaceAll('Ü', 'U').replaceAll('ü', 'u').replaceAll('Ö', 'O').replaceAll('ö', 'o').replaceAll('Ğ', 'G').replaceAll('ğ', 'g').replaceAll('İ', 'I').replaceAll('ı', 'i');
  }

  /// Text Widgetir donturur
  // Widget mcgText({Color color, double fontSize, FontWeight fontWeight, int maxLines, TextAlign textAlign = TextAlign.start}) {
  //   return Text(
  //     this,
  //     maxLines: maxLines,
  //     textAlign: textAlign,
  //     style: TextStyle(color: color, fontSize: fontSize, fontWeight: fontWeight),
  //   );
  // }

  ///BaslangiciBuyukYapar
  String? get capitalize => safeLength == 0
      ? this
      : safeLength == 1
          ? this!.toUpperCase()
          : this!.substring(0, 1).toUpperCase() + this!.substring(1);

  //kelimelerin sadece bas harflerini birlestirip buyutur
  String? get onlyCapitalLetters => safeLength == 0 ? this : (this!.split(" ").fold<String>('', (p, e) => e.safeLength > 0 ? p + e.substring(0, 1).toUpperCase() : p));

  //Kelimelerin istenilen kadar bas harglerini kesip buyutur.
  String? capitalLettersJoin({int characterCount = 1, String joinCharacter = '.'}) => safeLength == 0 ? this : (this!.split(" ").map((e) => (e.safeSubString(0, characterCount) ?? '').toUpperCase()).join(joinCharacter));

  ///String SiteUrl Sms Mail tel  ve map acar
  ///Map icin lat ve lon arasina / koy
  Future<void> launch(LaunchType launchType, {String mailSubject = ''}) async {
    late String item;
    if (launchType == LaunchType.mail) {
      item = 'mailto:$this?subject=$mailSubject';
    } else if (launchType == LaunchType.url) {
      if (!startsWithHttp) {
        item = 'https://$this';
      } else {
        item = this!;
      }
    } else if (launchType == LaunchType.call) {
      item = 'tel:$this';
    } else if (launchType == LaunchType.sms) {
      item = 'sms:$this';
    } else if (launchType == LaunchType.map) {
      item = 'https://www.google.com/maps/search/?api=1&query=${this!.split('/').first},${this!.split('/').last}';
    }
    final _uri = Uri.parse(item);
    if (await launcher.canLaunchUrl(_uri)) {
      await launcher.launchUrl(_uri);
    } else {
      OverAlert.show(
        message: (launchType == LaunchType.mail
                ? 'mailerr'
                : launchType == LaunchType.url
                    ? 'linkerr'
                    : launchType == LaunchType.sms || launchType == LaunchType.call
                        ? 'numbererr'
                        : 'dataerr')
            .translate,
        type: AlertType.danger,
      );
    }
  }

  void showAlert([AlertType? alertType]) => OverAlert.show(message: this!, type: alertType ?? AlertType.info);

  String? get mix {
    if (safeLength < 6) return this;
    var res = this! + 6.makeKey;
    for (var i = 0; i < res.length ~/ 2; i++) {
      res = res.substring(res.length - (i + 1)) + res.substring(i + 1, res.length - (i + 1)) + res.substring(0, i + 1);
    }
    return res;
  }

  String? get unMix {
    if (safeLength < 6) return this;
    var res = this!;
    for (var i = res.length ~/ 2 - 1; i > -1; i--) {
      res = res.substring(res.length - (i + 1)) + res.substring(i + 1, res.length - (i + 1)) + res.substring(0, i + 1);
    }
    return res.substring(0, res.length - 6);
  }

  String changeCharacter(int? no, String? character) {
    if (no == null || character == null || this == null) return this!;
    if (no >= this!.length) return this!;
    return this!.substring(0, no) + character + this!.substring(no + 1);
  }

  bool get everyCharacterIsAscii {
    for (var cu in this!.codeUnits) {
      if (cu > 127) return false;
    }
    return true;
  }

  bool get startsWithHttp => this != null && this!.startsWith('http');
}

enum LaunchType { url, mail, call, sms, map }

// extension MyObject on Object {
//   void selfPrint([String name]) => print('***** ${name == null ? '' : '$name: '}$this *****');
// }
